@@ -51,7 +51,7 @@ def plot_drawdown(data_df, column_name, error_message = 'no data'):
     return fig
 
 def dd_filter_daily(dataframe):
-    dataframe['day'] = dataframe.index.hour == 23 and dataframe.index.minute == 0
+    dataframe['day'] = (dataframe.index.hour == 23) & (dataframe.index.minute == 0)
     daily_aggregated_df = dataframe[dataframe['day']].copy()
     daily_aggregated_df['date'] = daily_aggregated_df.index
 
@@ -67,7 +67,7 @@ def dd_filter_daily(dataframe):
 
 def investigate_drawdown(data_df, column_toinvestigate = 'close'):
     data_df['normalized_strategy'] = data_df[column_toinvestigate]
-    daily_data_df = dd_filter_daily(data_df['normalized_strategy'].copy())
+    daily_data_df = dd_filter_daily(data_df[['normalized_strategy']].copy())
 
     ############# strategy drawdown
     dd_norm = riskmetrics.drawdown(daily_data_df['normalized_strategy'])
