@@ -220,9 +220,10 @@ def numba_indice_rebalancing_ok(daily_rebal, rebal_data, price_data, previous_pr
         values[i] = np.sum(weights[i, :])
     return weights, values
 
-@njit()
+#@njit()
 def numba_indice_rebalancing(early_rebal, rebal_data, price_data, previous_price_data, target_weights):
     values = np.zeros(price_data.shape[0])
+    turnover = np.zeros(price_data.shape[0])
     weights = np.zeros((price_data.shape[0],price_data.shape[1]))
     for i in range(price_data.shape[0]):
         if i == 0:
@@ -234,8 +235,10 @@ def numba_indice_rebalancing(early_rebal, rebal_data, price_data, previous_price
             previous_weights_have_drifted = np.sum(weights[i - 1, :] > target_weights) > 0
             must_rebalance = must_rebalance or previous_weights_have_drifted
         if must_rebalance:
+            ### the weights are reseted to target weights
             weights[i, :] = values[i-1]*flat_numba_drift_rebal(target_weights, price_data[i,:], previous_price_data[i,:])
         else :
+            ### the weights are left to drift
             weights[i, :] = flat_numba_drift_rebal(weights[i - 1, :], price_data[i,:], previous_price_data[i,:])
         values[i] = np.sum(weights[i, :])
     return weights, values
